@@ -490,7 +490,7 @@
 "MCMCmnl" <-
   function(formula, baseline=NULL, data=NULL,
            burnin = 1000, mcmc = 10000, thin=1,
-           mcmc.method = c("IndMH", "RWM", "slice"),
+           mcmc.method = "IndMH", 
            tune = 1.0, tdf=6, verbose = 0, seed = NA,
            beta.start = NA, b0 = 0, B0 = 0, ...) {
 
